@@ -1,9 +1,10 @@
 package URI::file::Unix;
 
-require URI::file::Base;
-@ISA=qw(URI::file::Base);
-
 use strict;
+use warnings;
+
+use parent 'URI::file::Base';
+
 use URI::Escape qw(uri_unescape);
 
 sub _file_extract_path
